@@ -1,7 +1,8 @@
-use crate::http::Header;
+use crate::http::header::HTTPResponseHeaders;
 use crate::http::response::HTTPResponse;
 use crate::http::Body;
 use crate::http::StatusCode;
+use crate::RSWEB_SERVER_STR;
 use std::collections::HashMap;
 
 /// an http route
@@ -42,11 +43,12 @@ impl Router {
     pub fn lookup(&self, key: String) -> Option<Route> {
         match self.routemap.get(&key) {
             Some(n) => {
-                let mut header = Header::new(StatusCode::MovedPermanently);
-
-                header.add_kv_pair(String::from("Location"), n.to_string());
                 let body = Body::new(String::new());
-                Some(Route::Route(HTTPResponse::new(header, body)))
+                Some(Route::Route(HTTPResponse::new(
+                    StatusCode::MovedPermanently,
+                    vec![HTTPResponseHeaders::Location(n.to_string()), HTTPResponseHeaders::Server(RSWEB_SERVER_STR.to_string())],
+                    body,
+                )))
             }
             None => self.aliasmap.get(&key).map(|n| Route::Alias(n.to_string())),
         }
